summaryrefslogtreecommitdiffstats
path: root/pytdeconfig.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 00:59:37 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 00:59:37 -0600
commitf050f7c84cccf297921968acd454e6a462e30857 (patch)
treed2dbec79b7ecb12d9dd28b20e491a454b18ecb52 /pytdeconfig.py
parent6b87edd9b7b08ca0030e5633e8a9653576f73a32 (diff)
downloadpytde-f050f7c84cccf297921968acd454e6a462e30857.tar.gz
pytde-f050f7c84cccf297921968acd454e6a462e30857.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'pytdeconfig.py')
-rw-r--r--pytdeconfig.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/pytdeconfig.py b/pytdeconfig.py
index e3f5fb8..9b2af0f 100644
--- a/pytdeconfig.py
+++ b/pytdeconfig.py
@@ -38,7 +38,7 @@ _pkg_config = {
'libdir': 'lib',
'pytde_kde_sip_flags': '-t ALL -x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6 -t KDE_3_5_3',
'pytde_mod_dir': '/usr/lib/python2.5/site-packages',
- 'pytde_modules': 'dcop tdecore tdefx tdeui kio tderesources kabc tdeutils kfile tdeparts tdehtml tdespell tdeprint tdemdi',
+ 'pytde_modules': 'dcop tdecore tdefx tdeui kio tderesources kabc tdeutils tdefile tdeparts tdehtml tdespell tdeprint tdemdi',
'pytde_sip_dir': '/usr/share/sip',
'pytde_version': 0x031000,
'pytde_version_str': '3.16.0'
@@ -155,7 +155,7 @@ class KioModuleMakefile(KdeuiModuleMakefile):
KdeuiModuleMakefile.finalise(self)
class KfileModuleMakefile(KioModuleMakefile):
"""The Makefile class for modules that %Import kfile.
"""
def finalise(self):
"""Finalise the macros.
@@ -164,7 +164,7 @@ class KfileModuleMakefile(KioModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kfile"))
+ self.extra_libs.append(self.module_as_lib("tdefile"))
KioModuleMakefile.finalise(self)
@@ -155,7 +155,7 @@ class KioModuleMakefile(KdeuiModuleMakefile):
KdeuiModuleMakefile.finalise(self)
class KfileModuleMakefile(KioModuleMakefile):
- """The Makefile class for modules that %Import kfile.
+ """The Makefile class for modules that %Import tdefile.
"""
def finalise(self):